#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-text
version:              1.1.1
visibility:           public
id:                   hslua-module-text-1.1.1-6KERLttvjX3FZUK5PMXPsi
key:                  hslua-module-text-1.1.1-6KERLttvjX3FZUK5PMXPsi
license:              MIT
copyright:            © 2017-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  6f0dd216fe2c5c7d01c68b86d9fe505d
exposed:              True
exposed-modules:      HsLua.Module.Text
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-text-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-text
hs-libraries:         HShslua-module-text-1.1.1-6KERLttvjX3FZUK5PMXPsi
depends:
    base-4.18.2.1 hslua-core-2.3.2.1-3tsNfZ2PPMpIrGoJYp3SDj
    hslua-marshalling-2.3.2-EQCZTvqDYkhHetwO8kOojF
    hslua-packaging-2.3.1-4pSKeXnzmdYDqoQde47g4S text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

